import { __decorate, __metadata } from 'tslib';
import { Component, ChangeDetectionStrategy, Input, Directive, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FieldWrapper, ɵFormlyAttributes, FormlyModule } from '@ngx-formly/core';
import { ReactiveFormsModule } from '@angular/forms';
import { IonicModule } from '@ionic/angular';

let FormlyWrapperFormField = class FormlyWrapperFormField extends FieldWrapper {
};
FormlyWrapperFormField = __decorate([
    Component({
        selector: 'formly-wrapper-ion-form-field',
        template: `
    <ion-item [lines]="to.itemLines">
      <ion-label [position]="to.labelPosition">
        {{ to.label }}
        <span *ngIf="to.required && to.hideRequiredMarker !== true">*</span>
      </ion-label>
      <ng-template #fieldComponent></ng-template>
    </ion-item>
    <ion-item lines="none" *ngIf="showError">
      <ion-label>
        <ion-text color="danger">
          <p>
            <formly-validation-message [field]="field"></formly-validation-message>
          </p>
        </ion-text>
      </ion-label>
    </ion-item>
  `,
        changeDetection: ChangeDetectionStrategy.OnPush
    })
], FormlyWrapperFormField);

let IonFormlyAttributes = class IonFormlyAttributes extends ɵFormlyAttributes {
    focusElement(element, value) {
        if (!element.setFocus || !value) {
            return;
        }
        if (!element.getInputElement()) {
            setTimeout(() => element.setFocus(), 300);
        }
        else {
            element.setFocus();
        }
    }
};
__decorate([
    Input('ionFormlyAttributes'),
    __metadata("design:type", Object)
], IonFormlyAttributes.prototype, "field", void 0);
IonFormlyAttributes = __decorate([
    Directive({
        // tslint:disable-next-line
        selector: '[ionFormlyAttributes]',
        host: {
            '(ionFocus)': 'onFocus($event)',
            '(ionBlur)': 'onBlur($event)',
            '(ionChange)': 'onChange($event)',
        },
    })
], IonFormlyAttributes);

let FormlyFormFieldModule = class FormlyFormFieldModule {
};
FormlyFormFieldModule = __decorate([
    NgModule({
        declarations: [FormlyWrapperFormField, IonFormlyAttributes],
        exports: [IonFormlyAttributes],
        imports: [
            CommonModule,
            ReactiveFormsModule,
            IonicModule,
            FormlyModule.forChild({
                wrappers: [
                    {
                        name: 'form-field',
                        component: FormlyWrapperFormField,
                    },
                ],
            }),
        ],
    })
], FormlyFormFieldModule);

/**
 * Generated bundle index. Do not edit.
 */

export { FormlyFormFieldModule, IonFormlyAttributes as ɵIonFormlyAttributes, FormlyWrapperFormField as ɵa };
//# sourceMappingURL=ngx-formly-ionic-form-field.js.map
